**************************************
* This program creates Appendix Table 1
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off						
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Appendix Table 1. Europe: 
* Controlling for Ex-post Developments
*****************************************

preserve
* Settings
local title = "Baseline"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 1
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA1.xls, ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "Unexpected fiscal consolidation"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = ggsb_gdp2012fall-ggsb_gdp2012fall[_n-2] - x
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
 	outreg2 using TA1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Ex-post change in sovereign CDS"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (sovcds_q4av-sovcds_q1av[_n-1])/100
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Ex-post change in bank CDS"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (bankcds_q4av-bankcds_q1av[_n-1])/100
bys ifscode: gen aux1 = (bankcds_q4av-bankcds_q1av[_n-1])/100
bys ifscode: gen aux2 = (sovcds_q4av-sovcds_q1av[_n-1])/100
rreg aux1 aux2 i.year if sample==1 & year>=2010 & year<=2011
predict yhat
bys ifscode: replace z = yhat if z==.
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Revision to initial debt ratio"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = gd_GDP2012fall[_n-2] - gd_GDP2010spring[_n-2] 
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore



log close

